saiorm
======

`Saiorm <https://weihaipy.github.io/saiorm>`_  is a simple library for accessing database.
It will take you have a easy way to use SQl database.

The goal is to be an asynchronous framework,but not now.

Documentation
-------------

 `Learn more <http://saiorm.readthedocs.io>`_.

Task
----

- [x] transform to sql
- [x] Support MySQL
- [ ] Support PostgreSQL
- [ ] Support SQLserver
- [ ] Support Oracle Database

If you want to support other database,just implement with the same API

like Saiorm.MySQL.CoherentDB and add a few driver code to Saiorm.init.
